use std::process::Command;
use clap::Parser;
use colored::Colorize;
use crate::commands::Cli;
use log::trace;
use crate::process::Process;

mod process;
mod commands;
mod package;
mod tmpfs;
mod logging;

fn main() {
    logging::setup_logger().expect("Unable to setup logger.");

    #[cfg(not(debug_assertions))]
    {
        #[cfg(target_family = "unix")]
        if unsafe { libc::getuid() } != 0 {
            use log::error;
            error!("pkgr must be run as root.");
            std::process::exit(1);
        }
    }

    trace!("Parsing command line arguments...");
    let c = Cli::parse();
    trace!("Command line arguments: {:?}", c);

    trace!("Executing command...");
    c.command.execute();
    trace!("Command executed.");

    trace!("Exiting...");
}
